@@ -3,7 +3,7 @@
    Copyright (C) 2018 Ole Aamot Software
    Author(s): Ole Aamot <ole@gnome.org>
    License: GNU GPL version 3
-   Version: 0.1.0 (2018-08-12)
+   Version: 0.1.3 (2020-06-20)
    Website: http://www.gingerblue.org/
  
  */
@@ -44,7 +44,7 @@ struct _GingerblueChord gbc[] = {
   {"Bb",   "Gingerblue_Guitar_Bb.wav", /* &console, */ '1', '3', '3', '3', '1', '-'},
   {"B",    "Gingerblue_Guitar_B.wav",  /* &console, */ '2', '4', '4', '4', '2', '0'},
   {"Bm",   "Gingerblue_Guitar_Bm.wav", /* &console, */ '2', '3', '4', '4', '2', '-'},
-  {NULL,NULL,NULL}
+  {NULL,NULL}
 };
 
 #endif /* _GINGERBLUE_CHORD_H_ */
