@@ -8,6 +8,7 @@
 
  */
 
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <gtk/gtkbox.h>
 #include <gtk/gtkbutton.h>
@@ -26,9 +27,9 @@ GtkWidget *main_config (gchar *location_data) {
        GtkContainer *Container;
        GtkWindow *gingerblue;
        gingerblue = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-       gtk_window_set_title (GTK_WINDOW (gingerblue), "Gingerblue Music Studio");
-       AddStudioButton = gtk_button_new_with_label("Add Studio");
-       NewStudioButton = gtk_button_new_with_label("New Studio");
+       gtk_window_set_title (GTK_WINDOW (gingerblue), _("Gingerblue Music Studio"));
+       AddStudioButton = gtk_button_new_with_label(_("Add Studio"));
+       NewStudioButton = gtk_button_new_with_label(_("New Studio"));
        Studio = gtk_box_new (GTK_ORIENTATION_VERTICAL, 8);
        Location = gtk_list_box_new ();
        gtk_container_add (GTK_CONTAINER (gingerblue), GTK_WIDGET (Studio));
