@@ -63,22 +63,22 @@ gb_file_config_load (GingerblueData *head, gchar *filename) {
 	}
 	cur = xmlDocGetRootElement (doc);
 	if (cur == NULL) {
-		fprintf (stderr, "Empty document\n");
+	        fprintf (stderr, _("Empty document\n"));
 		xmlFreeDoc (doc);
 		return NULL;
 	}
 	if (xmlStrcmp(cur->name, (const xmlChar *) "gingerblue")) {
-		fprintf(stderr, "Document of wrong type, root node != gingerblue\n");
+	        fprintf(stderr, _("Document of wrong type, root node != gingerblue\n"));
 		xmlFreeDoc (doc);
 		return NULL;
 	}
 	version = (gchar *) xmlGetProp (cur, (const xmlChar *)"version");
-	g_print ("Valid GNOME Gingerblue %s XML document %s\n", version, filename);
+	g_print (_("Valid GNOME Gingerblue %s XML document %s\n"), version, filename);
 	cur = cur->xmlChildrenNode;
 	while (cur != NULL) {
-		g_print ("Parsing GNOME Gingerblue %s XML document %s\n", version, filename);
+	  g_print (_("Parsing GNOME Gingerblue %s XML document %s\n"), version, filename);
 		if ((!xmlStrcmp(cur->name, (const xmlChar *) "line"))) {
-			g_print ("Found Line\n");
+		  g_print (_("Found Line\n"));
 			curr = g_new0(GingerblueData, 1);
 			curr->line = (gchar *) xmlNodeListGetString(doc, cur->xmlChildrenNode, 1);
 			g_print ("%s\n", curr->line);
@@ -90,7 +90,7 @@ gb_file_config_load (GingerblueData *head, gchar *filename) {
 			g_print ("Done with parsing Line\n");
 		}
 		if ((!xmlStrcmp(cur->name, (const xmlChar *) "musician"))) {
-			g_print ("Found Musician\n");
+			g_print (_("Found Musician\n"));
 			curr = g_new0(GingerblueData, 1);
 			curr->musician = (gchar *) xmlNodeListGetString(doc, cur->xmlChildrenNode, 1);
 			g_print ("%s\n", curr->musician);
@@ -99,10 +99,10 @@ gb_file_config_load (GingerblueData *head, gchar *filename) {
 			head = curr;
 			/* mem_volume = head */
 			/* volumes = g_list_append (gingerblue_volumes, (GingerblueData *)mem_volume); */
-			g_print ("Done with parsing Musician\n");
+			g_print (_("Done with parsing Musician\n"));
 		}
 		if ((!xmlStrcmp(cur->name, (const xmlChar *) "musical_instrument"))) {
-			g_print ("Found Musical Instrument\n");
+			g_print (_("Found Musical Instrument\n"));
 			curr = g_new0(GingerblueData, 1);
 			curr->musical_instrument = (gchar *) xmlNodeListGetString(doc, cur->xmlChildrenNode, 1);
 			g_print ("%s\n", curr->musical_instrument);
@@ -111,10 +111,10 @@ gb_file_config_load (GingerblueData *head, gchar *filename) {
 			head = curr;
 			/* mem_volume = head */
 			/* volumes = g_list_append (gingerblue_volumes, (GingerblueData *)mem_volume); */
-			g_print ("Done with parsing Musical Instrument\n");
+			g_print (_("Done with parsing Musical Instrument\n"));
 		}
 		if ((!xmlStrcmp(cur->name, (const xmlChar *) "volume"))) {
-			g_print ("Found Volume\n");
+			g_print (_("Found Volume\n"));
 			curr = g_new0(GingerblueData, 1);
 			curr->volume = (gchar *) xmlNodeListGetString(doc, cur->xmlChildrenNode, 1);
 			g_print ("%s\n", curr->volume);
@@ -123,11 +123,11 @@ gb_file_config_load (GingerblueData *head, gchar *filename) {
 			head = curr;
 			/* mem_volume = head */
 			/* volumes = g_list_append (gingerblue_volumes, (GingerblueData *)mem_volume); */
-			g_print ("Done with parsing Volume\n");
+			g_print (_("Done with parsing Volume\n"));
 		}
 		cur = cur->next;
 	}
-	g_print ("Finished parsing XML document\n");
+	g_print (_("Finished parsing XML document\n"));
 	xmlFreeDoc (doc);
 	return curr;
 }
