@@ -10,6 +10,7 @@
 
 #include <config.h>
 #include <stdlib.h>
+#include <glib/gi18n.h>
 #include <gst/gst.h>
 #include <gst/player/player.h>
 #include <gtk/gtk.h>
@@ -178,7 +179,7 @@ int main(int argc, char **argv)
 		{NULL, -1, "Instrument", GTK_ASSISTANT_PAGE_CONTENT, TRUE},
 		{NULL, -1, "Input Line", GTK_ASSISTANT_PAGE_CONTENT, TRUE},
 		{NULL, -1, "Label", GTK_ASSISTANT_PAGE_CONTENT, TRUE},
-		{NULL, -1, "Record", GTK_ASSISTANT_PAGE_CONFIRM, TRUE},
+		{NULL, -1, "Recording", GTK_ASSISTANT_PAGE_CONFIRM, TRUE},
 	};
 	datestamp = g_date_time_new_now_utc ();
 	gtk_init(&argc, &argv);
@@ -188,11 +189,9 @@ int main(int argc, char **argv)
 	gtk_window_set_title(GTK_WINDOW(introduction), "GNOME Gingerblue");
 	g_signal_connect(G_OBJECT(introduction), "destroy",
 			 G_CALLBACK(gtk_main_quit), NULL);
-	page[0].widget =
-	    gtk_label_new
-	    ("Welcome to GNOME Gingerblue!\n\nClick Next to setup a music recording session!");
+	page[0].widget = gtk_label_new(_("Welcome to GNOME Gingerblue!\n\nClick Next to setup a music recording session!"));
 	page[1].widget = gtk_box_new(FALSE, 5);
-	musician_label = gtk_label_new("Musician:");
+	musician_label = gtk_label_new(_("Musician:"));
 	musician_entry = gtk_entry_new();
 	gtk_entry_set_text(GTK_ENTRY(musician_entry), g_get_real_name());
 	gtk_box_pack_start(GTK_BOX(page[1].widget), GTK_WIDGET(musician_label),
@@ -200,38 +199,38 @@ int main(int argc, char **argv)
 	gtk_box_pack_start(GTK_BOX(page[1].widget), GTK_WIDGET(musician_entry),
 			   FALSE, FALSE, 5);
 	page[2].widget = gtk_box_new(FALSE, 5);
-	song_label = gtk_label_new("Song:");
+	song_label = gtk_label_new(_("Song:"));
 	song_entry = gtk_entry_new();
-	gtk_entry_set_text(GTK_ENTRY(song_entry), g_strconcat ("Song - ", g_date_time_format_iso8601 (datestamp), NULL));
+	gtk_entry_set_text(GTK_ENTRY(song_entry), g_strconcat (_("Song - "), g_date_time_format_iso8601 (datestamp), NULL));
 	gtk_box_pack_start(GTK_BOX(page[2].widget), GTK_WIDGET(song_label),
 			   FALSE, FALSE, 5);
 	gtk_box_pack_start(GTK_BOX(page[2].widget), GTK_WIDGET(song_entry),
 			   FALSE, FALSE, 5);
 	page[3].widget = gtk_box_new(FALSE, 5);
-	instrument_label = gtk_label_new("Instrument:");
+	instrument_label = gtk_label_new(_("Instrument:"));
 	instrument_entry = gtk_entry_new();
-	gtk_entry_set_text(GTK_ENTRY(instrument_entry), "Guitar");
+	gtk_entry_set_text(GTK_ENTRY(instrument_entry), _("Guitar"));
 	gtk_box_pack_start(GTK_BOX(page[3].widget),
 			   GTK_WIDGET(instrument_label), FALSE, FALSE, 5);
 	gtk_box_pack_start(GTK_BOX(page[3].widget),
 			   GTK_WIDGET(instrument_entry), FALSE, FALSE, 5);
 	page[4].widget = gtk_box_new(FALSE, 5);
-	line_label = gtk_label_new("Line Input:");
+	line_label = gtk_label_new(_("Line Input:"));
 	line_entry = gtk_entry_new();
-	gtk_entry_set_text(GTK_ENTRY(line_entry), "Mic");
+	gtk_entry_set_text(GTK_ENTRY(line_entry), _("Mic"));
 	gtk_box_pack_start(GTK_BOX(page[4].widget), GTK_WIDGET(line_label),
 			   FALSE, FALSE, 5);
 	gtk_box_pack_start(GTK_BOX(page[4].widget), GTK_WIDGET(line_entry),
 			   FALSE, FALSE, 5);
 	page[5].widget = gtk_box_new(FALSE, 5);
-	label_label = gtk_label_new("Label:");
+	label_label = gtk_label_new(_("Label:"));
 	label_entry = gtk_entry_new();
-	gtk_entry_set_text(GTK_ENTRY(label_entry), "GNOME");
+	gtk_entry_set_text(GTK_ENTRY(label_entry), _("GNOME"));
 	gtk_box_pack_start(GTK_BOX(page[5].widget), GTK_WIDGET(label_label),
 			   FALSE, FALSE, 5);
 	gtk_box_pack_start(GTK_BOX(page[5].widget), GTK_WIDGET(label_entry),
 			   FALSE, FALSE, 5);
-	recording_label = gtk_button_new_with_label("Record");
+	recording_label = gtk_button_new_with_label("Recording");
 	g_signal_connect(G_OBJECT(recording_label), "clicked",
 			 G_CALLBACK(gb_record_cb),
 			 g_strconcat(g_get_user_special_dir
@@ -239,11 +238,14 @@ int main(int argc, char **argv)
 				     g_get_real_name(), " - ",
 				     gtk_entry_get_text(GTK_ENTRY(song_entry)),
 				     ".ogg", NULL));
-	page[6].widget = gtk_button_new_with_label("Record");
+	page[6].widget = gtk_entry_new();
+	gtk_entry_set_text(GTK_ENTRY(page[6].widget), g_strconcat(g_get_user_special_dir
+								   (G_USER_DIRECTORY_MUSIC), "/",
+							           g_get_real_name(), " - ", gtk_entry_get_text(GTK_ENTRY(song_entry)), ".ogg", NULL));
 	gtk_box_pack_start(GTK_BOX(page[6].widget), GTK_WIDGET(recording_label),
 			   FALSE, FALSE, 5);
 	for (i = 0; i < 7; i++) {
-		page[i].index =
+	        page[i].index =
 		    gtk_assistant_append_page(GTK_ASSISTANT(introduction),
 					      GTK_WIDGET(page[i].widget));
 		gtk_assistant_set_page_title(GTK_ASSISTANT(introduction),
